@@ -22,9 +22,19 @@
 
 #define __GUCHARMAP_GUCHARMAP_H_INSIDE__
 
+#include <glib.h>
+
+#if defined(GUCHARMAP_DISABLE_DEPRECATION_WARNINGS) || !GLIB_CHECK_VERSION (2, 31, 0)
+#define GUCHARMAP_DEPRECATED
+#define GUCHARMAP_DEPRECATED_FOR(f)
+#else
+#define GUCHARMAP_DEPRECATED G_DEPRECATED
+#define GUCHARMAP_DEPRECATED_FOR(f) G_DEPRECATED_FOR(f)
+#endif
+
 #define GUCHARMAP_VERSION_MAJOR (3)
-#define GUCHARMAP_VERSION_MINOR (2)
-#define GUCHARMAP_VERSION_MICRO (1)
+#define GUCHARMAP_VERSION_MINOR (3)
+#define GUCHARMAP_VERSION_MICRO (0)
 
 #define GUCHARMAP_CHECK_VERSION(major,minor,micro) \
   (GUCHARMAP_VERSION_MAJOR > (major) || \
@@ -46,6 +56,8 @@
 
 #include <gucharmap/gucharmap-unicode-info.h>
 
+#undef GUCHARMAP_DEPRECATED
+#undef GUCHARMAP_DEPRECATED_FOR
 #undef __GUCHARMAP_GUCHARMAP_H_INSIDE__
 
 #endif /* #ifndef GUCHARMAP_H */
